Imports System.Windows.Forms

Module ErrorHandler

    ''' <summary>
    ''' Creates error message.
    ''' </summary>
    ''' <param name="modName">Module name, which handles an error Or in which the error has occured.</param>
    ''' <param name="funcName">Function name, which handles an error Or in which the error has occured.</param>
    ''' <param name="errorDescription">Error description.</param>
    Private Function getErrorMessage(ByVal modName As String, ByVal funcName As String, ByVal errorDescription As String) As String
        Return "Module: " & modName & Environment.NewLine &
                "Function: " & funcName & Environment.NewLine &
                "Error Description: " & errorDescription
    End Function

    ''' <summary>
    ''' Handles the error and shows a message box.
    ''' </summary>
    ''' <param name="modName">
    ''' Module name, in which the error has occurred.
    ''' </param>
    ''' <param name="funcName">
    ''' Function name, in which the error has occurred.
    ''' </param>
    ''' <param name="ex">
    ''' The exception generated in the described function of the described module.
    ''' </param>
    Public Sub HandleError(ByVal modName As String,
                           ByVal funcName As String,
                           ByVal ex As Exception)
        MessageBox.Show(getErrorMessage(modName, funcName, ex.Message),
                        "AccountsAndPositions", MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Sub

    ''' <summary>
    ''' Handles the error and shows a message box.
    ''' </summary>
    ''' <param name="modName">
    ''' Module name, in which the error has occurred.
    ''' </param>
    ''' <param name="funcName">
    ''' Function name, in which the error has occurred.
    ''' </param>
    ''' <param name="cqg_error">
    ''' CQGError object.
    ''' </param>
    Public Sub HandleError(ByVal modName As String,
                           ByVal funcName As String,
                           ByVal cqg_error As CQG.CQGError)
        MessageBox.Show(getErrorMessage(modName, funcName, cqg_error.Description),
                        "AccountsAndPositions", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
    End Sub

End Module
